# abadis.ir
دریافت اطلاعات از سایت آبادیس

```html

ab = Abadis().get_data_all_text_abadis("مسکن")
print(ab["مترادف"])
print(ab["متضاد"])
print(ab["برابر"])
print(ab["دانشنامه عمومی"])
print(ab["بیشترین کامند لایک شده"])
print(ab["کامنت"])سنجیدن

['آرامبخش', 'آرامشبخش', 'تسکینده', 'تسکیندهندهجا', 'جایگاه', 'خانه', 'ماوا', 'محل', 'مقام', 'مکان', 'منزل', 'نشیمن', 'وثاق']

None

['سرای', 'کاشانه', 'خانه', 'سرپناه', 'آرامبخش']

['مسکن', 'مسکن (ابهام زدایی)', 'مسکن (بازی ویدئویی)', 'مسکن (دارو)', 'مسکن (سبزوار)']

آرام بخش

['در اوستا " شینت " یعنی مسکن ، زیستگاه ، کاشانه .', 'واژه ایرانی است چون : واژه امروزین اسکان به دست آمده از لغت سغدی اسکا əskəw* که در متن های بازمانده از این زبان به معنای ساکن شدن اقامت کردن to dwell ثبت شده است. بدینسان روشن میشود واژگان عربی مسکن مسکونی سکونت جعلی هستند.  *پیرس: An Introduction to Manichean Sogdian by Harvard University', 'آرام بخش', 'داروییی برای بی حس کردن درد', 'painkillerداروی مسکن', 'barbiturate', 'Sedative', 'باششگاه ، در تاجیکستان به معنی محل اقامت و مسکن', 'مُسَکِّن به معنای تسکین دهنده ، آرامبخشمَسکَن به معنای خانه ، محل سکونت', 'اشکان جان چیزی که جعلیه حرفای تو بود رزا پالانی بی سواد و توله های بیسوادش', 'کاربر خر بالایی: شما کیره خر نخور قاجار و تورک کونی هایی که ایران رو به آشغال تبدیل کردن گمشو مغولاباد', 'مَسَکَن روستایی است متعلق به فیلسوف مشرق زمین حاج ملاهادی اسرار سبزواری که حتی بیوتات آن را نوه اش حاج شیخ ولی الله اسراری بنام خود به ثبت داده و در کودکی من صد خانوار از رجال ترابری باشتر در آن سکونت داشتند ومحصولات آن خربزه و غلات و هویج زردک و زیره وپنبه و امروز پسته می بانشد لذاانبار های حکیم بر اثر شن های روان در زیر خاک مدفون است و اگر هنوز که زنده هستم میراث فرهنگی دو عدد ماشین سنگین راه سازی بفرست عجایبی از زیر خاک بیرون میکنم تا رونق گردش گری گردد نام قدیم آن حفیر بود وبر اثز صاعقه و برق گود حفیر وسیل روستا ویران ولیحکیم فرزانه روستای جدید رادور اطرسیل بنا کرد و نامآنان رامسکن پارسی نمود وبا مسکن عربی هیچ سنخیت ندارد', 'palliative', 'anodyne']

'''
